pub struct Monitor {
pub name: Option<String>,
pub physical_height: u32,
pub physical_width: u32,
pub physical_position: IVec2,
pub refresh_rate_millihertz: Option<u32>,
pub scale_factor: f64,
pub video_modes: Vec<VideoMode>,
}Expand description
Represents an available monitor as reported by the user’s operating system, which can be used to query information about the display, such as its size, position, and video modes.
Each monitor corresponds to an entity and can be used to position a monitor using
MonitorSelection::Entity.
Warning
This component is synchronized with winit through bevy_winit, but is effectively
read-only as winit does not support changing monitor properties.
Fields
name: Option<String>The name of the monitor
physical_height: u32The height of the monitor in physical pixels
physical_width: u32The width of the monitor in physical pixels
physical_position: IVec2The position of the monitor in physical pixels
refresh_rate_millihertz: Option<u32>The refresh rate of the monitor in millihertz
scale_factor: f64The scale factor of the monitor
video_modes: Vec<VideoMode>The video modes that the monitor supports
Implementations