pub struct OnMonitor(pub Entity);Expand description
Represents the relationship between a Window and the Monitor it is currently on.
Note
This component is inserted after window creation, this means that there is a small period of time when the Window exists, but does not know the monitor it is on.
Tuple Fields
0: EntityTrait Implementations
Sourceimpl Component for OnMonitor
impl Component for OnMonitor
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
Sourcetype Mutability = Immutable
type Mutability = Immutable
A marker type to assist Bevy with determining if this component is
mutable, or immutable. Mutable components will have
Component<Mutability = Mutable>,
while immutable components will instead have Component<Mutability = Immutable>. Read moreSourcefn register_required_components(
_requiree: ComponentId,
required_components: &mut RequiredComponentsRegistrator<'_, '_>,
)
fn register_required_components( _requiree: ComponentId, required_components: &mut RequiredComponentsRegistrator<'_, '_>, )
Registers required components. Read more
Sourcefn on_insert() -> Option<ComponentHook>
fn on_insert() -> Option<ComponentHook>
Sourcefn on_discard() -> Option<ComponentHook>
fn on_discard() -> Option<ComponentHook>
Sourcefn clone_behavior() -> ComponentCloneBehavior
fn clone_behavior() -> ComponentCloneBehavior
Called when registering this component, allowing to override clone function (or disable cloning altogether) for this component. Read more
Sourcefn map_entities<M: EntityMapper>(this: &mut Self, mapper: &mut M)
fn map_entities<M: EntityMapper>(this: &mut Self, mapper: &mut M)
Maps the entities on this component using the given
EntityMapper. This is used to remap entities in contexts like scenes and entity cloning.
When deriving Component, this is populated by annotating fields containing entities with #[entities] Read moreSourcefn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
fn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
Returns
ComponentRelationshipAccessor required for working with relationships in dynamic contexts. Read moreSourcefn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourceimpl Relationship for OnMonitor
impl Relationship for OnMonitor
Sourceconst ALLOW_SELF_REFERENTIAL: bool = false
const ALLOW_SELF_REFERENTIAL: bool = false
If
true, a relationship is allowed to point to its own entity. Read moreSourcetype RelationshipTarget = HasWindows
type RelationshipTarget = HasWindows
The
Component added to the “target” entities of this Relationship, which contains the list of all “source”
entities that relate to the “target”.Sourcefn from(entity: Entity) -> Self
fn from(entity: Entity) -> Self
Creates this
Relationship from the given entity.Sourcefn set_risky(&mut self, entity: Entity)
fn set_risky(&mut self, entity: Entity)
Changes the current
Entity ID of the entity containing the RelationshipTarget to another one. Read moreSourcefn on_insert(world: DeferredWorld<'_>, _: HookContext)
fn on_insert(world: DeferredWorld<'_>, _: HookContext)
Sourcefn on_discard(world: DeferredWorld<'_>, _: HookContext)
fn on_discard(world: DeferredWorld<'_>, _: HookContext)